@@ -3,7 +3,7 @@
     que imprime listas de podem ou não incluir listas aninhadas
 """
 
-def print_lol(the_list):
+def print_lol(the_list, level=0):
     """
         Esta função requer um argumento possicional chamado "the_list", que é
         qualquer lista python (de possiveis listas aninhadas). Cada item de dados na
@@ -11,8 +11,11 @@ def print_lol(the_list):
     """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item)
+            print_lol(each_item, level+1)
         else:
+            for tab_level in range(level):
+                print("\t", end='')
             print(each_item)
 
 
+
